import { named } from './lib-reexport2.js';
console.log('side-effect', named);
export { named as default };
